==> react-native-ui-view-0.0.11.tgz: package/esm/components/Cell/cell.js <==
import React from 'react';
import { View, StyleSheet, Text, TouchableHighlight } from 'react-native';
import { Theme } from '../../components/Styles/theme';
import Icon from '../Icon';
const WithWrap = props => {
    const { children, clickable, style, onPress } = props;
    if (clickable) {
        return (React.createElement(TouchableHighlight, { style: style, activeOpacity: 0.6, underlayColor: Theme.fillBody, onPress: onPress },
            React.createElement(React.Fragment, null, children)));
    }
    return React.createElement(View, { style: style }, children);
};
const Cell = props => {
    const { title, label, value, border = true, isLink, centerRightText = true, rightIconName = 'right', rightIconSize = 24, rightIconColor = Theme.colorTextSecondary, clickable, style, onPress, renderLeftIcon, } = props;
    return (React.createElement(WithWrap, { style: [styles.container, border && styles.border, style], clickable: clickable, onPress: onPress },
        React.createElement(View, { style: styles.left },
            React.createElement(View, { style: styles.titleWrap },
                renderLeftIcon ? React.createElement(View, { style: styles.iconWrap }, renderLeftIcon()) : null,
                React.createElement(Text, { style: styles.titleText }, title)),
            !!label && (React.createElement(View, { style: styles.titleLabelWrap },
                React.createElement(Text, { numberOfLines: 1, style: styles.titleLabel }, label)))),
        React.createElement(View, { style: { alignSelf: centerRightText ? 'center' : 'flex-start' } },
            value && React.createElement(Text, null, title),
            isLink && React.createElement(Icon, { name: rightIconName, size: rightIconSize, color: rightIconColor }))));
};
const styles = StyleSheet.create({
    container: {
        flexDirection: 'row',
        alignItems: 'center',
        paddingVertical: 12,
        paddingHorizontal: 10,
    },
    border: {
        borderBottomColor: Theme.borderLightColor,
        borderBottomWidth: 0.5,
    },
    left: {
        flex: 1,
    },
    titleWrap: {
        flexDirection: 'row',
        alignItems: 'center',
    },
    iconWrap: {
        marginRight: 6,
    },
    titleText: {
        fontSize: 16,
        color: Theme.colorTextParagraph,
    },
    titleLabelWrap: {
        marginTop: 4,
    },
    titleLabel: {
        fontSize: 12,
        color: Theme.colorTextCaption,
    },
});
export default Cell;

==> react-native-ui-view-0.1.0.tgz: package/esm/components/Cell/cell.js <==
import React from 'react';
import { View, StyleSheet, Text } from 'react-native';
import { Theme } from '../../components/Styles/theme';
import Icon from '../Icon';
import Touchable from '../Touchable';
const WithWrap = props => {
    const { children, clickable, style, onPress } = props;
    if (clickable) {
        return (React.createElement(Touchable, { style: style, underlayColor: Theme.fillBody, onPress: onPress },
            React.createElement(React.Fragment, null, children)));
    }
    return React.createElement(View, { style: style }, children);
};
const Cell = props => {
    const { title, label, value, border = true, isLink, centerRightText = true, rightIconName = 'right', rightIconSize = 24, rightIconColor = Theme.colorTextSecondary, clickable, style, onPress, renderLeftIcon, } = props;
    return (React.createElement(WithWrap, { style: [styles.container, border && styles.border, style], clickable: clickable, onPress: onPress },
        React.createElement(View, { style: styles.left },
            React.createElement(View, { style: styles.titleWrap },
                renderLeftIcon ? React.createElement(View, { style: styles.iconWrap }, renderLeftIcon()) : null,
                React.createElement(Text, { style: styles.titleText }, title)),
            !!label && (React.createElement(View, { style: styles.titleLabelWrap },
                React.createElement(Text, { numberOfLines: 1, style: styles.titleLabel }, label)))),
        React.createElement(View, { style: { alignSelf: centerRightText ? 'center' : 'flex-start' } },
            value && React.createElement(Text, null, title),
            isLink && React.createElement(Icon, { name: rightIconName, size: rightIconSize, color: rightIconColor }))));
};
const styles = StyleSheet.create({
    container: {
        flexDirection: 'row',
        alignItems: 'center',
        paddingVertical: 12,
        paddingHorizontal: 10,
    },
    border: {
        borderBottomColor: Theme.borderLightColor,
        borderBottomWidth: 0.5,
    },
    left: {
        flex: 1,
    },
    titleWrap: {
        flexDirection: 'row',
        alignItems: 'center',
    },
    iconWrap: {
        marginRight: 6,
    },
    titleText: {
        fontSize: 16,
        color: Theme.colorTextParagraph,
    },
    titleLabelWrap: {
        marginTop: 4,
    },
    titleLabel: {
        fontSize: 12,
        color: Theme.colorTextCaption,
    },
});
export default Cell;
